@@ -2,7 +2,6 @@ import logging
 
 try:
     import sentry_sdk
-    from sentry_sdk.integrations.asgi import SentryAsgiMiddleware
 except ImportError:
     sentry = False
 else:
@@ -39,9 +38,6 @@ def install_fastapi(settings: Settings):
 
     if sentry:
         sentry_sdk.init(dsn=getattr(settings, "SENTRY_DSN", ""))
-        app.add_middleware(
-            SentryAsgiMiddleware,
-        )
 
     @app.exception_handler(DomainException)
     def unicorn_domain_exception_handler(request: Request, exc: DomainException):
@@ -51,6 +47,9 @@ def install_fastapi(settings: Settings):
         else:
             logger.error(f"{exc.code} - {exc.message}")
 
+        if sentry:
+            sentry_sdk.capture_exception(exc)
+
         return JSONResponse(
             status_code=exc.status_code,
             content=ErrorMessage(
@@ -64,6 +63,9 @@ def install_fastapi(settings: Settings):
     def unicorn_exception_handler(request: Request, exc: Exception):
         logging.error(exc)
 
+        if sentry:
+            sentry_sdk.capture_exception(exc)
+
         return JSONResponse(
             status_code=500,
             content=ErrorMessage(
