@@ -19,13 +19,13 @@ def get_payload(fractal: Fractal, *, typ: str = "access"):
     return _get_payload
 
 
-def get_payload_roles(fractal: Fractal, *, roles: list):
+def get_payload_roles(fractal: Fractal, *, roles: list, typ: str = "access"):
     assert hasattr(fractal, "context")
     context = getattr(fractal, "context")
     assert hasattr(context, "token_service")
 
     def _get_payload(token: str = Depends(oauth2_scheme)) -> TokenPayloadRoles:
-        payload = TokenPayloadRoles(**context.token_service.verify(token))
+        payload = TokenPayloadRoles(**context.token_service.verify(token, typ=typ))
         if not set(payload.roles or []) & set(roles):
             raise NotAllowedException("No permission!")
         return payload
